/*******************
VARIABLES
*******************/
var creativeId = "DeluxeBanner";
var creativeVersion = "2.0.0";
var lastModified = "2017-11-01";
var lastUploaded = "2017-11-01";
var templateVersion = "2.0.24";
var templateName = "cf_deluxe_banner_video_1x1_" + creativeVersion + "_6267"; // cf_[format_name]_[template_name]_[wxh]_version_BlockID

var video;
var videoRef, videoThumb, videoContainerRef, playPauseBtn, muteUnmuteBtn, lastFrame;

var adId, rnd, uid;

/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	if (window.adkit) {
		adkit.onReady(initializeCreative);
	}
	else {
		initializeCreative();
	}
}

function initializeCreative(event) {

	try { //try/catch just in case localPreview.js is not included
		if (window.localPreview) {
			window.initializeLocalPreview(); //in localPreview.js
		}
	}
	catch (e) {}

	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function() {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function() {
		eventManager.apply(this, arguments);
	}, this);

	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr == "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);

	initializeGlobalVariables();
    lastFrame.src = "./images/video.jpg";

	window.registerInteraction = function() {}; //overwrite rI function because it will never actually be called
	initializeVideo();
    addEventListeners();

	setCreativeVersion();
}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;
	video = document.getElementById("video");
    
	videoContainerRef = document.getElementById("video-container");
    playPauseBtn = document.getElementById("play-pause");
    muteUnmuteBtn = document.getElementById("mute-unmute");
    lastFrame = document.getElementById("lastframe");
}

function initializeVideo() {
	var videoTracker = new EBG.VideoModule(video);

	video.classList.remove("hide");
}

function addEventListeners() {
    document.body.addEventListener("click", onClickthrough);
    videoContainerRef.addEventListener("click", onClickthroughVideo);
    playPauseBtn.addEventListener("click", toggleVideoPlay);
    muteUnmuteBtn.addEventListener("click",toggleAudio );
    video.addEventListener("ended", handleVideoEnd);
    video.addEventListener("playing", handlePlaying);
    video.addEventListener("pause", handlePause);
}

/*******************
EVENT HANDLERS
*******************/
function onClickthrough(e) {
    myStopPropagation(e);
	EB.clickthrough("click_header");
}
function onClickthroughVideo(e) {
    myStopPropagation(e);
	EB.clickthrough("click_videoplayer");
}

function handlePlaying(){
    setBtnStatusTo("pause");
    hideLastframe();
}

function handlePause(){
    setBtnStatusTo("play");
   hideLastframe();
}

function handleVideoEnd(){
    setBtnStatusTo("replay");
    showLastframe();
}

function toggleVideoPlay(e){
    myStopPropagation(e);
    if(checkVideoPlaying()){
        video.pause();
        setBtnStatusTo("play");
    }else{
        video.play();
        setBtnStatusTo("pause");
    }
}

function toggleAudio(e){
    myStopPropagation(e);
     if(video.muted){
       video.muted = false;
        setBtnStatusTo("mute");
    }else{
       video.muted = true;
        setBtnStatusTo("unmute");
    }
}

function showLastframe(){
    lastFrame.style.opacity = 1;
}
function hideLastframe(){
    lastFrame.style.opacity = 0;
}

function setBtnStatusTo(_status){
    switch(_status) {
      case "play":
        playPauseBtn.children[0].src = "images/controls/play.svg";
        break;
      case "pause":
        playPauseBtn.children[0].src = "images/controls/pause.svg";
        break;
    case "mute":
        muteUnmuteBtn.children[0].src = "images/controls/unmute.svg";
        break;
    case "unmute":
         muteUnmuteBtn.children[0].src = "images/controls/mute.svg";
        break;
    case "replay":
        playPauseBtn.children[0].src = "images/controls/replay.svg";
        break;
      default:
        // code block
    }
}

function checkVideoPlaying(){
    if(video.currentTime > 0 && !video.paused && !video.ended){
        return true;
    }else{
        return false;
    }
}

/*******************
UTILITIES
*******************/

function setCreativeVersion() {
	sendMessage("setCreativeVersion", {
		creativeId: creativeId + " - " + templateName,
		creativeVersion: creativeVersion,
		creativeLastModified: lastModified,
		uid: uid
	});
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {

	//note: the message type we're sending is also the name of the function inside
	//		the custom script's messageHandlers object, so the case must match.

	if (!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function eventManager(event) {

	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);

	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
			case "sendCreativeId":
				creativeIFrameId = msg.data.creativeIFrameId;
				//addCustomScriptEventListener('pageScroll', onPageScroll);
				sendMessage("dispatchScrollPos", {
					uid: uid
				});
				if (creativeContainerReady)
					creativeContainerReady();
				break;
			case "eventCallback": // Handle Callback
				var list = msg.data.listenerIds;
				var length = list.length;
				for (var i = 0; i < length; i++) {
					try {
						var t = listenerQueue[list[i]];
						if (!t) continue;
						t.callback(msg.data);
					}
					catch (e) {}
				}
				break;
		}
	}
}

function myStopPropagation(e){
	
	if (!e)
	  e = window.event;

	//IE9 & Other Browsers
	if (e.stopPropagation) {
	  e.stopPropagation();
	}
	//IE8 and Lower
	else {
	  e.cancelBubble = true;
	}
}


window.addEventListener("message", function() {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);

/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);